@@ -1,7 +1,5 @@
-from sgqlc.operation import Operation
-
 from politylink.graphql.client import GraphQLClient
-from politylink.graphql.schema import Query, _MinutesFilter, _Neo4jDateTimeInput
+from politylink.graphql.schema import _MinutesFilter, _Neo4jDateTimeInput
 
 
 class MinutesFinder:
@@ -13,14 +11,8 @@ class MinutesFinder:
         self.client = GraphQLClient(**kwargs)
 
     def find(self, text, dt=None):
-        op = Operation(Query)
         minutes_filter = _MinutesFilter(None)
         minutes_filter.name_contains = text
         if dt:
             minutes_filter.start_date_time = _Neo4jDateTimeInput(year=dt.year, month=dt.month, day=dt.day)
-        op.minutes(filter=minutes_filter)
-
-        data = self.client.endpoint(op)
-        GraphQLClient.validate_response_or_raise(data)
-        minutes = (op + data).minutes
-        return minutes
+        return self.client.get_all_minutes(fields=['id', 'name', 'start_date_time'], filter_=minutes_filter)
